==> ansible-navigator-2.0.0a0.tar.gz: ansible-navigator-2.0.0a0/src/ansible_navigator/runner/command_base.py <==
"""Herein lies the base class for running commands using ansible-runner.

All attributes common to a subprocess or async command are defined here.
"""

import sys

from typing import List
from typing import Optional

from ..utils.functions import shlex_join
from .base import Base


class CommandBase(Base):
    # pylint: disable=too-many-arguments
    """Base class for runner command interaction."""

    def __init__(
        self,
        executable_cmd: str,
        cmdline: Optional[List] = None,
        playbook: Optional[str] = None,
        inventory: Optional[List] = None,
        wrap_sh: Optional[bool] = False,
        **kwargs,
    ):
        """Handle common arguments of ``run_command`` interface for ``ansible-runner``.

        :param executable_cmd: The command to be invoked
        :param cmdline: A list of arguments to be passed to the executable command
        :param playbook: The playbook file name to run
        :param inventory: List of path to the inventory files
        :param wrap_sh: Wrap the command with `sh -c`, disregarding stderr output. Runner will
            pass --tty in almost all (default) cases. When that flag is given, docker and podman
            will combine the process's stdout and stderr into just stdout. Wrapping the command
            with sh allows us to disregard the stderr output when we only care about stdout.
        :param kwargs: The arguments for the runner call
        """
        self._executable_cmd = executable_cmd
        self._cmdline: List[str] = cmdline if isinstance(cmdline, list) else []
        self._playbook = playbook
        self._inventory: List[str] = inventory if isinstance(inventory, list) else []
        self._wrap_sh = wrap_sh
        super().__init__(**kwargs)

    def generate_run_command_args(self) -> None:
        """Generate arguments required to be passed to ansible-runner."""
        if self._playbook:
            self._cmdline.insert(0, self._playbook)

        for inv in self._inventory:
            self._cmdline.extend(["-i", inv])

        if self._wrap_sh:
            self._cmdline.insert(0, self._executable_cmd)
            self._runner_args["executable_cmd"] = "/bin/sh"
            cmd_args = shlex_join(self._cmdline)
            self._runner_args["cmdline_args"] = ["-c", f"exec 2>/dev/null; {cmd_args}"]
        else:
            self._runner_args["executable_cmd"] = self._executable_cmd
            self._runner_args["cmdline_args"] = self._cmdline

        if self._navigator_mode == "stdout":
            self._runner_args.update(
                {"input_fd": sys.stdin, "output_fd": sys.stdout, "error_fd": sys.stderr},
            )

        for key, value in self._runner_args.items():
            self._logger.debug("Runner arg: %s:%s", key, value)

==> ansible-navigator-3.6.0.tar.gz: ansible-navigator-3.6.0/src/ansible_navigator/runner/command_base.py <==
"""Herein lies the base class for running commands using ansible-runner.

All attributes common to a subprocess or async command are defined here.
"""

from __future__ import annotations

import sys

from .base import Base


class CommandBase(Base):
    """Base class for runner command interaction."""

    def __init__(
        self,
        executable_cmd: str,
        cmdline: list | None = None,
        playbook: str | None = None,
        inventory: list | None = None,
        **kwargs,
    ):
        """Handle common arguments of ``run_command`` interface for ``ansible-runner``.

        :param executable_cmd: The command to be invoked
        :param cmdline: A list of arguments to be passed to the executable command
        :param playbook: The playbook file name to run
        :param inventory: List of path to the inventory files
        :param kwargs: The arguments for the runner call
        """
        self._executable_cmd = executable_cmd
        self._cmdline: list[str] = cmdline if isinstance(cmdline, list) else []
        self._playbook = playbook
        self._inventory: list[str] = inventory if isinstance(inventory, list) else []
        super().__init__(**kwargs)

    def generate_run_command_args(self) -> None:
        """Generate arguments required to be passed to ansible-runner."""
        if self._playbook:
            self._cmdline.insert(0, self._playbook)

        for inv in self._inventory:
            self._cmdline.extend(["-i", inv])

        self._runner_args["executable_cmd"] = self._executable_cmd
        self._runner_args["cmdline_args"] = self._cmdline

        if self._navigator_mode == "stdout":
            self._runner_args.update(
                {"input_fd": sys.stdin, "output_fd": sys.stdout, "error_fd": sys.stderr},
            )

        for key, value in self._runner_args.items():
            self._logger.debug("Runner arg: %s:%s", key, value)
